@@ -1,4 +1,5 @@
 import hashlib
+import io
 import json
 import logging
 import os
@@ -6,7 +7,7 @@ import select
 import socket
 import sys
 import zipfile
-from contextlib import contextmanager
+from contextlib import contextmanager, redirect_stdout
 from email.utils import parseaddr
 from functools import wraps
 from getpass import getuser
@@ -320,9 +321,13 @@ def deploy(
         BytesIO(CADDYFILE.format(host=dns_host, tls=tls).encode()),
         "dallinger/Caddyfile",
     )
-    executor.run("docker-compose -f ~/dallinger/docker-compose.yml up -d")
-    print("Launched http and postgresql servers. Starting experiment")
+    print("Removing any pre-existing Redis volumes.")
+    remove_redis_volumes(app_name, executor)
 
+    print("Launching http and postgresql servers.")
+    executor.run("docker-compose -f ~/dallinger/docker-compose.yml up -d")
+
+    print("Starting experiment.")
     experiment_uuid = str(uuid4())
     if app_name:
         experiment_id = app_name
@@ -463,6 +468,18 @@ def get_experiment_id_from_archive(archive_path):
             return fh.read().decode("utf-8")
 
 
+def remove_redis_volumes(app_name, executor):
+    redis_volume_name = f"{app_name}_dallinger_{app_name}_redis_data"
+    stdout = io.StringIO()
+    with redirect_stdout(stdout):
+        try:
+            executor.run(f"docker volume rm '{redis_volume_name}'")
+        except ExecuteException:
+            err = stdout.getvalue()
+            if "No such volume" not in err:
+                raise ExecuteException(err)
+
+
 @docker_ssh.command()
 @server_option
 def apps(server):
@@ -676,7 +693,7 @@ class Executor:
 
         Adapted from paramiko "interactive.py" demo.
         """
-        from paramiko.py3compat import u
+        from paramiko.util import u
 
         chan = self.client.get_transport().open_session()
         chan.exec_command(cmd)
